==> macroscope-1.0.2278.tar.bz2: macroscope-1.0.2278/src/libksys/object.cpp <==
/*-
 * Copyright 2007 Guram Dukashvili
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
//---------------------------------------------------------------------------
#include <adicpp/ksys.h>
//---------------------------------------------------------------------------
namespace ksys {
//---------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
//---------------------------------------------------------------------------
uint8_t Object::fabric_[sizeof(ObjectFabric)];
//---------------------------------------------------------------------------
void Object::initialize()
{
  new (fabric_) ObjectFabric;
}
//---------------------------------------------------------------------------
void Object::cleanup()
{
  fabric().~ObjectFabric();
}
//---------------------------------------------------------------------------
utf8::String Object::className() const
{
  return typeid(*this).name();
}
//---------------------------------------------------------------------------
utf8::String Object::classId() const
{
  return guidToBase32(stringToGUID("44F611AD-FE5F-413D-BF12-46BF74AAB7A9"));
}
//---------------------------------------------------------------------------
utf8::String Object::objectName() const
{
  return utf8::ptr2Str(this);
}
//---------------------------------------------------------------------------
utf8::String Object::objectId() const
{
  return utf8::ptr2Str(this);
}
//---------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
//---------------------------------------------------------------------------
utf8::String ObjectFabric::className() const
{
  return typeid(*this).name();
}
//---------------------------------------------------------------------------
utf8::String ObjectFabric::classId() const
{
  return guidToBase32(stringToGUID("3AA709B7-813A-47EF-B91C-74B6ED2C433B"));
}
//---------------------------------------------------------------------------
} // namespace ksys
//---------------------------------------------------------------------------

==> macroscope-1.0.3787.tar.bz2: macroscope-1.0.3787/src/libksys/object.cpp <==
/*-
 * Copyright 2007-2008 Guram Dukashvili
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
//---------------------------------------------------------------------------
#include <adicpp/ksys.h>
//---------------------------------------------------------------------------
namespace ksys {
//---------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
//---------------------------------------------------------------------------
//uint8_t Object::fabric_[sizeof(ObjectFabric)];
//---------------------------------------------------------------------------
void Object::initialize()
{
  //new (fabric_) ObjectFabric;
}
//---------------------------------------------------------------------------
void Object::cleanup()
{
  //fabric().~ObjectFabric();
}
//---------------------------------------------------------------------------
const char * Object::getClassName(const void * thisObject)
{
#ifdef _MSC_VER
  return typeid(*(Object *) thisObject).raw_name();
#else
  return typeid(*(Object *) thisObject).name();
#endif
}
//---------------------------------------------------------------------------
const char * Object::className() const
{
  return NULL;
}
//---------------------------------------------------------------------------
guid_t Object::classId() const
{
  return stringToGUID("44F611AD-FE5F-413D-BF12-46BF74AAB7A9");
}
//---------------------------------------------------------------------------
utf8::String Object::objectName() const
{
  return utf8::ptr2Str(this);
}
//---------------------------------------------------------------------------
guid_t Object::objectId() const
{
  guid_t g;
  memset(&g,0,sizeof(g));
  return g;
}
//---------------------------------------------------------------------------
/////////////////////////////////////////////////////////////////////////////
//---------------------------------------------------------------------------
guid_t ObjectFabric::classId() const
{
  return stringToGUID("3AA709B7-813A-47EF-B91C-74B6ED2C433B");
}
//---------------------------------------------------------------------------
} // namespace ksys
//---------------------------------------------------------------------------
